import os

from alei_utils import adapt_logger
import logging
from utils.concat_utils import concatenate_parquet_files, take_files_from_path, delete_duplicate_rows
import timeit

if "LOGGING_LEVEL" in os.environ:
    logging.basicConfig(level=os.getenv("LOGGING_LEVEL", default="DEBUG"))
logger = logging.getLogger(__name__)

adapter = adapt_logger(logger, {
    "servico": "IJ",
    "modulo": "IJ_CONCATENADOR_MAIN"
    })

def concatenate_all_from_path(path_in,path_out = None, file_name = None):
    '''
    Concatena todos os arquivos parquet de um determinado path
    :param path_in: path de entrada
    :param path_out: path de saida
    :param file_name: nome do arquivo de saida
    :return: dataframe concatenado
    '''
    try:
        parquet_files = take_files_from_path(path_in)
        inicio = timeit.default_timer()
        df = delete_duplicate_rows(concatenate_parquet_files(parquet_files))
        fim = timeit.default_timer()
        tempo = fim-inicio
        adapter.debug(
            f"tempo da concatenacao: {round(round(tempo,2)/60,2)} minutos",
            evento_status="E_S",
            tag_evento="TEMPO DE EXECUCAO"
        )
        adapter.info(
            "concatenacao finalizada",
            evento_status="E_S",
            tag_evento="CONCATECAO FINALIZADA"
        )
        adapter.debug(
            "concatenacao finalizada",
            evento_status="E_S",
            tag_evento="CONCATECAO FINALIZADA"
        )
        if path_out is not None and file_name is not None:
            df.to_parquet(path_out + '/' + file_name, index=False)
        return df
    except Exception as erro:
        adapter.error(
            f"Erro ao concatenar os arquivos: {erro}",
            evento_status="E_E",
            tag_evento="CONCATECAO ENCERRADA COM ERRO"
        )

def concatenate_files(files):
    try:
        inicio = timeit.default_timer()
        df = concatenate_parquet_files(files)
        fim = timeit.default_timer()
        tempo = fim-inicio
        adapter.debug(
            f"tempo da concatenacao: {round(round(tempo,2)/60,2)} minutos",
            evento_status="E_S",
            tag_evento="TEMPO DE EXECUCAO"
        )
        adapter.info(
            "concatenacao finalizada",
            evento_status="E_S",
            tag_evento="CONCATECAO FINALIZADA"
        )
        adapter.debug(
            "concatenacao finalizada",
            evento_status="E_S",
            tag_evento="CONCATECAO FINALIZADA"
        )
        return df
    except Exception as erro:
        adapter.error(
            f"Erro ao concatenar os arquivos: {erro}",
            evento_status="E_E",
            tag_evento="CONCATECAO ENCERRADA COM ERRO"
        )



from setuptools import setup

with open("README.md", "r") as arq:
    readme = arq.read()

setup(
    name='sabia-utils',
    version='0.0.4',
    license='MIT License',
    author='Pedro Jesus',
    long_description=readme,
    long_description_content_type="text/markdown",
    author_email='pedrovitora.jesus@gmail.com',
    keywords='sabia utils',
    description=u'Group of utilities for Sabia',
    packages=['sabia_utils', 'sabia_utils.utils'],
    install_requires=[
    'pandas==1.4.3',
    'alei-utils==0.1.3',
    'pyarrow==6.0.1'
    ],)



import logging
import pandas as pd
import glob
import os
from alei_utils import adapt_logger
import timeit


if "LOGGING_LEVEL" in os.environ:
    logging.basicConfig(level=os.getenv("LOGGING_LEVEL", default="DEBUG"))
logger = logging.getLogger(__name__)

adapter = adapt_logger(logger, {
    "servico": "IJ",
    "modulo": "IJ_CONCATENADOR_PACKAGE"
    })


def concatenate_parquet_files(files):
    try:
        inicio = timeit.default_timer()
        adapter.info(
            "concatenacao iniciada",
            evento_status="E_S",
            tag_evento="CONCATENACAO INICIADA"
        )
        ct = 0
        parquet = []
        for f in files:
            try:
                parquet.append(pd.read_parquet(f))
                df = pd.concat(parquet, ignore_index=True)
                ct += 1
                if (ct >= 10):
                    tempo = timeit.default_timer()-inicio
                    ct = 0
                    adapter.debug(
                        f"tempo da concatenacao parcial: {tempo} segundos",
                        evento_status="E_S",
                        tag_evento="TEMPO DE EXECUCAO"
                    )
                adapter.debug(
                    f"concatenando parquet: {f}",
                    evento_status="E_S",
                    tag_evento=f"CONCATENANDO PARQUET: {f}"
                )

            except Exception as error:
                adapter.error(
                    f"erro ao concatenar arquivo: {f} {error}",
                    evento_status="E_E",
                    tag_evento=f"ERRO AO CONCATENAR ARQUIVO: {f}"
                )
        return df
    except Exception as error:
        adapter.error(
            f"erro ao concatenar arquivos: {error}",
            evento_status="E_E",
            tag_evento="ERRO AO CONCATENAR ARQUIVOS"
        )
        return None


def delete_duplicate_rows(df):
    try:
        adapter.info(
            "remocao de duplicatas iniciada",
            evento_status="E_S",
            tag_evento="REMOCAO DE DUPLICATAS INICIADA"
        )
        adapter.debug(
            "remocao de duplicatas iniciada",
            evento_status="E_S",
            tag_evento="REMOCAO DE DUPLICATAS INICIADA"
        )
        return df.drop_duplicates(subset='processo_numero', keep='last')
    except Exception as error:
        adapter.error(
            f"erro ao remover duplicatas: {error}",
            evento_status="E_E",
            tag_evento="ERRO AO REMOVER DUPLICATAS"
        )
        return None


def take_files_from_path(path):
    try:
        adapter.info(
            "busca de arquivos iniciada",
            evento_status="E_S",
            tag_evento="BUSCA DE ARQUIVOS INICIADA"
        )
        adapter.debug(
            "busca de arquivos iniciada",
            evento_status="E_S",
            tag_evento="BUSCA DE ARQUIVOS INICIADA"
        )
        return glob.glob(os.path.join(path, "*.parquet"))
    except Exception as error:
        adapter.error(
            f"erro ao buscar arquivos: {error}",
            evento_status="E_E",
            tag_evento="ERRO AO BUSCAR ARQUIVOS"
        )
        return None

